Crate bdk_tx

Crate bdk_tx 

bdk_tx

Re-exports

pub use miniscript;
pub use miniscript::bitcoin;

Structs

CannotMeetTarget
Error when the selection is impossible with the input candidates
CanonicalUnspents
Our canonical view of unspent outputs.
CoinbaseMismatch
Mismatch between the expected and actual value of Transaction::is_coinbase.
FinalizeMap
Holds the results of finalization
Finalizer
Finalizer
Input
Single-input plan.
InputCandidates
Input candidates.
InputGroup
Input group. Cannot be empty.
MissingOutputs
Occurs when we are missing outputs.
OriginalTxHasNoInputsAvailable
Occurs when the given original tx has no input spend that is still available for spending.
OriginalTxStats
Rbf original tx stats.
Output
Builder output
PsbtParams
Parameters for creating a psbt.
RbfParams
Rbf params.
RbfSet
Set of txs to replace.
Selection
Final selection of inputs and outputs.
Selector
A coin selector
SelectorParams
Parameters for creating tx.
Signer
A PSBT signer
TxStatus
Confirmation status of a tx data.

Enums

ChangePolicyType
Change policy type
CreatePsbtError
Occurs when creating a psbt fails.
ExtractReplacementsError
Error when attempting to do extract_replacements.
FromPsbtInputError
Error creating Input from a PSBT input
GetForeignUnspentError
Canonical unspents error
IntoSelectionError
Occurs when we cannot find a solution for selection.
PolicyFailure
Occurs when a must-select policy cannot be fulfilled.
ScriptSource
Source of the output script pubkey
SelectorError
Selector error

Functions

filter_unspendable_now
Filter out inputs that cannot be spent now.
group_by_spk
Default group policy.
no_filtering
No filtering.
selection_algorithm_lowest_fee_bnb
Select for lowest fee with bnb

Type Aliases

DefiniteDescriptor
Definite descriptor.
TxWithStatus
Tx with confirmation status.