Selector

Struct Selector 

pub struct Selector<'c> { /* private fields */ }
A coin selector

Implementations

Source

impl<'c> Selector<'c>

pub fn new( candidates: &'c InputCandidates, params: SelectorParams, ) -> Result<Self, SelectorError>

Create new input selector.

Errors
  • If we are unable to create a change policy from the params.
  • If the target is unreachable given the total input value.
pub fn inner(&self) -> &CoinSelector<'c>

Get the inner coin selector.

pub fn inner_mut(&mut self) -> &mut CoinSelector<'c>

Get a mutable reference to the inner coin selector.

pub fn target(&self) -> Target

Coin selection target.

pub fn change_policy(&self) -> ChangePolicy

Coin selection change policy.

pub fn select_with_algorithm<F, E>(&mut self, algorithm: F) -> Result<(), E>
where F: FnMut(&mut Selector<'_>) -> Result<(), E>,

Select with the provided algorithm.

pub fn select_all(&mut self)

Select all.

pub fn select_until_target_met(&mut self) -> Result<(), InsufficientFunds>

Select in order until target is met.

pub fn has_change(&self) -> Option<bool>

Whether we added the change output to the selection.

Return None if target is not met yet.

pub fn try_finalize(&self) -> Option<Selection>

Try get final selection.

Return None if target is not met yet.